@@ -7,6 +7,10 @@ mod text_index;
 
 #[cfg(feature = "lsp")]
 pub use self::text_index::*;
+#[cfg(feature = "lsp")]
+pub use lsp_types;
 
 pub use self::{builder::ASTBuilder, cst_node::CSTNode, text_store::TextStore};
-pub use url::Url;
\ No newline at end of file
+pub use url::Url;
+pub use ropey::Rope;
+pub use dashmap::{DashMap, DashSet};
